# Welcome to Serious Scaffold Pybind11's documentation

<!-- Extract content from start line 1 of README.md -->

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

## Content

```{toctree}
:maxdepth: 2
:titlesonly:
:caption: Guide
:glob:

Overview <self>
```

<!-- Disable to show when there is no api generation in the docs -->

```{toctree}
:maxdepth: 1
:titlesonly:
:caption: API docs

api/index
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
